@@ -3,7 +3,7 @@ use warnings;
 
 package WebService::IMDBAPI;
 {
-  $WebService::IMDBAPI::VERSION = '1.130030';
+  $WebService::IMDBAPI::VERSION = '1.130150';
 }
 
 # ABSTRACT: Interface to http://imdbapi.org/
@@ -49,10 +49,15 @@ sub search_by_title {
     my $response = $self->_do_search($options);
     if ( $response->is_success ) {
 
+        my $content = decode_json( $response->content );
+
         my @results;
-        for ( @{ decode_json( $response->content ) } ) {
-            my $result = WebService::IMDBAPI::Result->new( %{$_} );
-            push( @results, $result );
+        if ( ref($content) eq 'ARRAY' ) {
+
+            for ( @{ decode_json( $response->content ) } ) {
+                my $result = WebService::IMDBAPI::Result->new( %{$_} );
+                push( @results, $result );
+            }
         }
         return \@results;
     }
@@ -72,8 +77,12 @@ sub search_by_id {
     my $response = $self->_do_search($options);
     if ( $response->is_success ) {
 
-        my $result = WebService::IMDBAPI::Result->new(
-            %{ decode_json( $response->content ) } );
+        my $content = decode_json( $response->content );
+
+        if ( $content->{error} ) {
+            return;
+        }
+        my $result = WebService::IMDBAPI::Result->new( %{$content} );
         return $result;
     }
     else {
@@ -116,7 +125,7 @@ WebService::IMDBAPI - Interface to http://imdbapi.org/
 
 =head1 VERSION
 
-version 1.130030
+version 1.130150
 
 =head1 SYNOPSIS
 
